@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -84,9 +84,11 @@ class SCD30(I2CSensor):
 
     def sensor_exists(self):
         """
-        test if sensor is plugged in and works proper
-        :returns: True if test was successful otherwise False
-        :rtype: bool
+        Test if sensor is plugged in and works proper
+
+        Returns:
+            bool: True if test was successful otherwise False
+
         """
         serial_number = self.get_serial_number()
 
@@ -100,12 +102,26 @@ class SCD30(I2CSensor):
         return exists
 
     def get_firmware(self):
+        """
+        Read firmware version.
+
+        Returns:
+            str: Firmware version identifier.
+
+        """
         data = self.txrx(self.__cmd_get_firmware_version, readlen=3)
         if data is not None:
             return f"{data[0]}.{data[1]}"
         return False
 
     def get_asc_status(self):
+        """
+        Get automatic self-calibration (acs) status.
+
+        Returns:
+            bool: True if asc active, false otherwise.
+
+        """
         data = self.txrx(self.__cmd_asc_get_state, readlen=3)
 
         if data is not None:
@@ -117,6 +133,13 @@ class SCD30(I2CSensor):
                 return None
 
     def get_measurement_intervall(self):
+        """
+        Read current measurement interval.
+
+        Returns:
+            int: Seconds per measurement
+
+        """
         data = None
         for i in range(self._max_attempts):
             data = self.txrx(self.__cmd_get_measurement_interval, readlen=3)
@@ -127,20 +150,26 @@ class SCD30(I2CSensor):
         return data
 
     def stop_measurement(self):
+        """Stop measurement run."""
         self.txrx(self.__cmd_stop_cont_meas, readlen=0)
 
     def reset(self):
         """
-        reseting the sensor
-        :return: True for successful reset else False
+        Reseting the sensor
         """
         self.txrx(self.__cmd_soft_rst, readlen=0)
         time.sleep(0.5)
 
     def crc_check(self, ba):
         """
-        :param ba: [BYTEARRAY] byte array with crc check sum every third entry
-        :return: Array of booleans indicated correct crc check sums
+        Assert if received data is valid
+
+        Args:
+            ba (bytearray): Byte array with a crc check sum at every third entry
+
+        Returns:
+            bytearray: Array of booleans indicating correct crc check sums
+
         """
         crc = [False] * int(len(ba) / 3)
         if len(ba) % 3 != 0:
@@ -157,8 +186,10 @@ class SCD30(I2CSensor):
     def get_serial_number(self):
         """
         Get device serial number
-        :return: [STRING] not supported
-        :raises: Warning
+
+        Returns:
+            str: serial number or bool if no number has been read
+
         """
         for i in range(self._max_attempts):
             data = self.txrx(self.__cmd_get_serial_number, crc=False, readlen=9)
@@ -176,9 +207,11 @@ class SCD30(I2CSensor):
 
     def set_asc(self, state):
         """
-        setup automatic self calibration
-        :param amb_pressure: ambiet pressure (default==off)
-        ranges from 700-1400mBar
+        Setup automatic self calibration
+
+        Args:
+            state (bool): activate or deactivate automatic self-calibration
+
         """
         current_state = self.get_asc_status()
         if current_state != state:
@@ -186,6 +219,7 @@ class SCD30(I2CSensor):
                 self.txrx(self.__cmd_asc_activate, readlen=0)
             else:
                 self.txrx(self.__cmd_asc_deactivate, readlen=0)
+
         time.sleep(self.measurement_intervall + 1)
 
     def prepare_measurement(self, amb_pressure=0):
@@ -193,13 +227,16 @@ class SCD30(I2CSensor):
         self.start_continuous_measurement(amb_pressure=amb_pressure)
         self._logger.debug("Measurement prep. took %d seconds.", int(time.time() - t0))
 
-    def start_continuous_measurement(self, amb_pressure=0):
+    def start_continuous_measurement(self, amb_pressure: int = 0):
         """
-        initialises a continuous measurement of CO2 temperature and humidity
-        :param amb_pressure: ambiet pressure (default==off)
-        ranges from 700-1400mBar
-        :return: [BOOLEAN]: continuous measurement established
-        (True = successful | False = failed)
+        Initializes a continuous measurement of CO2 temperature and humidity
+
+        Args:
+            amb_pressure (int): ambiet pressure (default==off) ranges from 700-1400mBar
+
+        Returns:
+            bool: Continuous measurement established successfully (true) or failed (false)
+
         """
         intervall = self.get_measurement_intervall()
         if isinstance(intervall, int):
@@ -227,11 +264,17 @@ class SCD30(I2CSensor):
                 crc_init=self._crc_check_init,
             )[0]
         cmd = self.__cmd_cont_meas + [p_msb, p_lsb, p_crc]
-        # self._logger.warning(f"init cmd not send (legacy) {cmd}")
         self.txrx(cmd)
         time.sleep(self.measurement_intervall + 1)
 
     def get_data_rdy(self):
+        """
+        Check if measurement data is available
+
+        Returns:
+            bool: True if data is present, false otherwise.
+
+        """
         data = self.txrx(self.__cmd_get_data_rdy, readlen=3)
         if data is not None and data[1] == 0x01:
             return True
@@ -240,11 +283,11 @@ class SCD30(I2CSensor):
 
     def get_data(self):
         """
-        :param scale_factor: [INT] sensor specific parameter for the
-        calculation of the volume flow
-        :param offset: [INT] sensor specific parameter for the calculation of
-        the volume flow
-        :return: [DICT] data dictionary
+        Read CO2 concentration, temperature and humidty
+
+        Returns:
+            dict: data dictionary (keys: error, values)
+
         """
 
         # Wait until data is ready
