@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -9,8 +9,8 @@ Example script for running a measurement using i2c senors only.
 import argparse
 import time
 import logging
-from pySerialMeasurement.devices.FTDI import init_all_i2c, UM232H
-from pySerialMeasurement.tools.bulk import setup, ThreadWithReturnValue
+from pyserialsensors.devices.FTDI import init_all_i2c, UM232H
+from pyserialsensors.tools.bulk import setup, ThreadWithReturnValue
 
 # logging.basicConfig(level=logging.DEBUG)
 
@@ -26,10 +26,10 @@ def runMeasurement(setup, n):
             for sensor in mux.sensors:
                 val = sensor["obj"].get_data()
                 out = f"{val['sensor_type']: >10}"
-                if val["serialno"] is None:
+                if val["SENSORserial"] is None:
                     out += f"{'': >20}"
                 else:
-                    out += f"{val['serialno']: >20}"
+                    out += f"{val['SENSORserial']: >20}"
                 results = [0] * len(val["values"])
                 units = []
                 for i in range(n):
